export interface CsrKeyCacheFactory {
    <V>(config?: Partial<CsrKeyCacheFactoryConfig<V>>): CsrKeyCache<V>;
}
export interface CsrKeyCacheFactoryConfig<V> {
    cache: Cache<string, V> | LruCacheOptions<V>;
    keylength: number;
    csrng: Csrng;
}
export interface Csrng {
    (length: number): Uint8Array;
}
export interface LruCacheOptions<V> {
    max?: number;
    maxAge?: number;
    length?: (value: V) => number;
    dispose?: (key: any, value: V) => void;
    stale?: boolean;
}
export interface CsrKeyCache<V> {
    set(val: V, expire?: number): string | false;
    del(key: string): void;
    get(key: string): V;
    has(key: string): boolean;
}
export interface Cache<K, V> {
    set(key: K, val: V, expire?: number): void;
    del(key: K): void;
    get(key: K): V;
    has(key: K): boolean;
}
declare const getCsrKeyCache: CsrKeyCacheFactory;
export default getCsrKeyCache;
