"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var base64 = require("base64-js");
var SPEC_DEFAULTS = {
    keylength: 32
};
var CsrKeyCacheClass = (function () {
    function CsrKeyCacheClass(cache, keylength, getRandomBytes) {
        this.cache = cache;
        this.keylength = keylength;
        this.getRandomBytes = getRandomBytes;
    }
    CsrKeyCacheClass.prototype.set = function (val, expire) {
        var key = this.getNewKey();
        this.cache.set(key, val, expire);
        return this.cache.has(key) && key;
    };
    CsrKeyCacheClass.prototype.del = function (key) {
        return this.cache.del(key);
    };
    CsrKeyCacheClass.prototype.get = function (key) {
        return this.cache.get(key);
    };
    CsrKeyCacheClass.prototype.has = function (key) {
        return this.cache.has(key);
    };
    CsrKeyCacheClass.prototype.getNewKey = function () {
        var rnd = this.getRandomBytes(this.keylength);
        var key = base64.fromByteArray(rnd);
        return !this.cache.has(key) ? key : this.getNewKey();
    };
    CsrKeyCacheClass.getInstance = function (opts) {
        var specs = __assign({}, SPEC_DEFAULTS, opts);
        var cache = isCache(specs.cache)
            ? specs.cache
            : getLruCache(specs.cache);
        var getRandomBytes = specs.csrng || require('randombytes');
        return new CsrKeyCacheClass(cache, specs.keylength, getRandomBytes);
    };
    return CsrKeyCacheClass;
}());
function isCache(val) {
    return !!val && [val.set, val.get, val.del, val.has].every(isFunction);
}
function isFunction(val) {
    return typeof val === 'function';
}
var LRU_CACHE_DEFAULTS = {
    max: 1024,
    maxAge: 15 * 60 * 1000
};
function getLruCache(opts) {
    var newLruCache = require('lru-cache');
    var config = __assign({}, LRU_CACHE_DEFAULTS, opts);
    return newLruCache(config);
}
var getCsrKeyCache = CsrKeyCacheClass.getInstance;
exports.default = getCsrKeyCache;
